rse.app package — The Research Software Encyclopedia 11 documentation

# rse.app package

## Subpackages

- rse.app.views package
  - Submodules
  - rse.app.views.main module
  - rse.app.views.repositories module
  - Module contents

## Submodules

## rse.app.api module

## rse.app.config module

Copyright (C) 2020 Vanessa Sochat.

This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0. If a copy of the MPL was not distributed with this file, You can obtain one at http://mozilla.org/MPL/2.0/.

## rse.app.server module

## Module contents